Skip to main content Module paths Copy item path Source APPLIED_FILE PJ-side state file name (under <pj>/.kata/). GLOBAL_CONFIG_FILE Global config file name (under <config-dir>/kata/). PJ_STATE_DIR PJ-side state directory name (under each managed project root). applied_path <pj_root>/.kata/applied.tomlfind_pj_root Walk up from start looking for the nearest directory containing
.kata/applied.toml. Returns the project root (the dir containing
.kata/), not the state file itself. global_config_dir Returns the directory used for kata’s global config. global_config_path Returns the path to the global config.toml. template_cache_dir Returns the directory used for cached template repositories.